@@ -1,15 +1,17 @@
 from simple_aws_lambda_maker.errors import NoFunctionsSpecified, NoSuchGroup, GroupNotSpecified
 from simple_aws_lambda_maker.maker import LambdaMaker
 
-from input_algorithms import spec_base as sb
+from delfick_project.norms import sb
 from textwrap import dedent
 
 available_actions = {}
 
+
 def an_action(func):
     available_actions[func.__name__] = func
     return func
 
+
 @an_action
 def help(collector, **kwargs):
     """List the available_tasks"""
@@ -22,6 +24,7 @@ def help(collector, **kwargs):
         print("\n".join("\t{0}".format(line) for line in dedent(action.__doc__).split("\n")))
         print("")
 
+
 @an_action
 def deploy(collector, group, **kwargs):
     """Deploy our lambda functions"""
