@@ -7,24 +7,23 @@ from simple_aws_lambda_maker.collector import Collector
 from simple_aws_lambda_maker.errors import NoSuchTask
 from simple_aws_lambda_maker import VERSION
 
-from input_algorithms.spec_base import NotSpecified
-from delfick_app import App, DelayedFileType
+from delfick_project.app import App, OptionalFileType
+from delfick_project.norms import sb
 import logging
 
 log = logging.getLogger("simple_aws_lambda_maker.executor")
 
+
 class App(App):
     VERSION = VERSION
-    cli_categories = ['salm']
+    cli_categories = ["salm"]
     cli_description = "Very simple deployer for python lambdas"
-    cli_environment_defaults = {"SALM_CONFIG": ("--salm-config", './salm.yml')}
-    cli_positional_replacements = [('--task', 'help'), ('--group', NotSpecified)]
+    cli_environment_defaults = {"SALM_CONFIG": ("--salm-config", "./salm.yml")}
+    cli_positional_replacements = [("--task", "help"), ("--group", sb.NotSpecified)]
 
     def execute(self, args_obj, args_dict, extra_args, logging_handler, no_docker=False):
-        args_dict["salm"]["config"] = args_dict["salm"]["config"](optional=True) or NotSpecified
-
         config_name = None
-        if args_dict["salm"]["config"] is not NotSpecified:
+        if args_dict["salm"]["config"] is not sb.NotSpecified:
             config_name = args_dict["salm"]["config"].name
 
         collector = Collector()
@@ -44,32 +43,31 @@ class App(App):
         logging.getLogger("botocore").setLevel([logging.CRITICAL, logging.ERROR][verbose or debug])
 
     def specify_other_args(self, parser, defaults):
-        parser.add_argument("--salm-config"
-            , help = "The config file specifying what simple_aws_lambda_maker should care about"
-            , type = DelayedFileType("r")
-            , **defaults["--salm-config"]
-            )
+        parser.add_argument(
+            "--salm-config",
+            help="The config file specifying what simple_aws_lambda_maker should care about",
+            type=OptionalFileType("r"),
+            **defaults["--salm-config"]
+        )
 
-        parser.add_argument("--dry-run"
-            , help = "Should salm take any real action or print out what is intends to do"
-            , dest = "salm_dry_run"
-            , action = "store_true"
-            )
+        parser.add_argument(
+            "--dry-run",
+            help="Should salm take any real action or print out what is intends to do",
+            dest="salm_dry_run",
+            action="store_true",
+        )
 
-        parser.add_argument("--task"
-            , help = "The task to run"
-            , dest = "salm_task"
-            , **defaults["--task"]
-            )
+        parser.add_argument(
+            "--task", help="The task to run", dest="salm_task", **defaults["--task"]
+        )
 
-        parser.add_argument("--group"
-            , help = "The group to work on"
-            , dest = "salm_group"
-            , **defaults["--group"]
-            )
+        parser.add_argument(
+            "--group", help="The group to work on", dest="salm_group", **defaults["--group"]
+        )
 
         return parser
 
+
 main = App.main
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
